summaryrefslogtreecommitdiff
path: root/vdr.c
diff options
context:
space:
mode:
authorKlaus Schmidinger <vdr@tvdr.de>2021-04-06 08:48:35 +0200
committerKlaus Schmidinger <vdr@tvdr.de>2021-04-06 08:48:35 +0200
commit23d986657a5a4e7d086932d528715aaf8875bad3 (patch)
treef7066dc39ee0281b39bd9efadd9dd2d83f11ca6e /vdr.c
parent8f1419fff59acea5c57e861819111cfc38dd193d (diff)
downloadvdr-23d986657a5a4e7d086932d528715aaf8875bad3.tar.gz
vdr-23d986657a5a4e7d086932d528715aaf8875bad3.tar.bz2
Spawned timers that don't use VPS now automatically adjust their start/stop times to changes in the respective event's times
Diffstat (limited to 'vdr.c')
-rw-r--r--vdr.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/vdr.c b/vdr.c
index 8b8cca39..d3a29872 100644
--- a/vdr.c
+++ b/vdr.c
@@ -22,7 +22,7 @@
*
* The project's page is at http://www.tvdr.de
*
- * $Id: vdr.c 5.1 2020/12/26 15:49:01 kls Exp $
+ * $Id: vdr.c 5.2 2021/04/06 08:48:35 kls Exp $
*/
#include <getopt.h>
@@ -1109,8 +1109,8 @@ int main(int argc, char *argv[])
Timers->SetSyncStateKey(StateKeySVDRPRemoteTimersPoll); // setting events shall not trigger a remote timer poll...
if (Timers->SetEvents(Schedules))
TimersModified = true;
- if (Timers->SpawnPatternTimers(Schedules)) {
- StateKeySVDRPRemoteTimersPoll.Reset(); // ...but spawning new timers must!
+ if (Timers->SpawnPatternTimers(Schedules) | Timers->AdjustSpawnedTimers()) { // this really is '|', not '||'!
+ StateKeySVDRPRemoteTimersPoll.Reset(); // ...but spawning new timers or adjusting spawned timers must!
TimersModified = true;
}
SchedulesStateKey.Remove();